-- Copyright (c) 2011 Cloudera, Inc. All rights reserved.
--
-- Version 1 of the CMF schema. The base schema; modifications are made via
-- separate pieces of migration code.
--

-- The schema version, should be checked by the server during startup
create table SCHEMA_VERSION (
    VERSION integer not null
) engine=InnoDB;

-- Update this value when the schema changes, also during migration
insert into SCHEMA_VERSION set VERSION=1;

create table AUDITS (
    AUDIT_ID bigint not null,
    SERVICE_ID bigint,
    ROLE_ID bigint,
    CREATED_INSTANT bigint,
    MESSAGE longtext,
    primary key (AUDIT_ID)
) engine=InnoDB;

create table COMMANDS (
    COMMAND_ID bigint not null,
    NAME varchar(255) not null,
    STATE varchar(255),
    START_INSTANT bigint,
    END_INSTANT bigint,
    ACTIVE integer,
    RESULT_MESSAGE longtext,
    RESULT_DATA mediumblob,
    RESULT_DATA_MIME_TYPE varchar(255),
    RESULT_DATA_FILENAME varchar(255),
    SUCCESS bit,
    SERVICE_ID bigint not null,
    ROLE_ID bigint,
    PARENT_ID bigint,
    primary key (COMMAND_ID)
) engine=InnoDB;

create table CONFIGS (
    CONFIG_ID bigint not null,
    ROLE_ID bigint,
    ROLE_TYPE varchar(255),
    ATTR varchar(255) not null,
    VALUE longtext not null,
    SERVICE_ID bigint not null,
    primary key (CONFIG_ID)
) engine=InnoDB;

create table CREDENTIALS (
    CREDENTIAL_ID bigint not null,
    PRINCIPAL varchar(255) not null unique,
    KEYTAB mediumblob not null,
    primary key (CREDENTIAL_ID)
) engine=InnoDB;

create table HOSTS (
    HOST_ID bigint not null,
    OPTIMISTIC_LOCK_VERSION bigint not null,
    HOST_IDENTIFIER varchar(255) not null unique,
    NAME varchar(255),
    IP_ADDRESS varchar(255),
    RACK_ID varchar(255),
    STATUS varchar(255),
    primary key (HOST_ID)
) engine=InnoDB;

create table PROCESSES (
    PROCESS_ID bigint not null,
    NAME varchar(255) not null,
    ROLE_ID bigint,
    COMMAND_ID bigint,
    HOST_ID bigint not null,
    PROCESS_USER varchar(255),
    PROCESS_GROUP varchar(255),
    PROGRAM varchar(255),
    ARGUMENTS longtext,
    RUNNING bit,
    RUN_GENERATION bigint,
    ONE_OFF bit,
    CONFIGURATION_DATA mediumblob,
    STATUS_LINKS longtext,
    RESOURCES longtext,
    ENVIRONMENT longtext,
    REFRESH_FILES longtext,
    primary key (PROCESS_ID)
) engine=InnoDB;

create table ROLES (
    ROLE_ID bigint not null,
    NAME varchar(255) not null unique,
    HOST_ID bigint,
    ROLE_TYPE varchar(255),
    CONFIGURED_STATUS varchar(255),
    STATUS varchar(255),
    SERVICE_ID bigint,
    primary key (ROLE_ID)
) engine=InnoDB;

create table SERVICES (
    SERVICE_ID bigint not null,
    OPTIMISTIC_LOCK_VERSION bigint not null,
    NAME varchar(255) not null unique,
    SERVICE_TYPE varchar(255),
    primary key (SERVICE_ID)
) engine=InnoDB;

create table SETTINGS (
    SETTINGS_ID bigint not null,
    OPTIMISTIC_LOCK_VERSION bigint not null,
    HEARTBEAT_INTERVAL bigint,
    MISSED_HB_CONCERNING bigint,
    MISSED_HB_BAD bigint,
    PASSWORD_HASH varchar(255),
    PASSWORD_SALT bigint,
    WEB_TLS bit,
    AGENT_TLS bit,
    NEED_AGENT_VALIDAITON bit,
    KEYSTORE_PATH longtext,
    KEYSTORE_PASSWORD varchar(255),
    TRUSTSTORE_PATH longtext,
    TRUSTSTORE_PASSWORD varchar(255),
    HTTP_PORT integer,
    HTTPS_PORT integer,
    AGENT_PORT integer,
    SECURITY_REALM varchar(255),
    primary key (SETTINGS_ID)
) engine=InnoDB;

alter table COMMANDS 
    add index FK_COMMAND_ROLE (ROLE_ID), 
    add constraint FK_COMMAND_ROLE 
    foreign key (ROLE_ID) 
    references ROLES (ROLE_ID);

alter table COMMANDS 
    add index FK_COMMAND_PARENT (PARENT_ID), 
    add constraint FK_COMMAND_PARENT 
    foreign key (PARENT_ID) 
    references COMMANDS (COMMAND_ID);

alter table COMMANDS 
    add index FK_COMMAND_SERVICE (SERVICE_ID), 
    add constraint FK_COMMAND_SERVICE 
    foreign key (SERVICE_ID) 
    references SERVICES (SERVICE_ID);

alter table CONFIGS 
    add index FK_CONFIG_ROLE (ROLE_ID), 
    add constraint FK_CONFIG_ROLE 
    foreign key (ROLE_ID) 
    references ROLES (ROLE_ID);

alter table CONFIGS 
    add index FK_CONFIG_SERVICE (SERVICE_ID), 
    add constraint FK_CONFIG_SERVICE 
    foreign key (SERVICE_ID) 
    references SERVICES (SERVICE_ID);

alter table PROCESSES 
    add index FK_PROCESS_HOST (HOST_ID), 
    add constraint FK_PROCESS_HOST 
    foreign key (HOST_ID) 
    references HOSTS (HOST_ID);

alter table PROCESSES 
    add index FK_PROCESS_ROLE (ROLE_ID), 
    add constraint FK_PROCESS_ROLE 
    foreign key (ROLE_ID) 
    references ROLES (ROLE_ID);

alter table PROCESSES 
    add index FK_PROCESS_COMMAND (COMMAND_ID), 
    add constraint FK_PROCESS_COMMAND 
    foreign key (COMMAND_ID) 
    references COMMANDS (COMMAND_ID);

alter table ROLES 
    add index FK_ROLE_HOST (HOST_ID), 
    add constraint FK_ROLE_HOST 
    foreign key (HOST_ID) 
    references HOSTS (HOST_ID);

alter table ROLES 
    add index FK_ROLE_SERVICE (SERVICE_ID), 
    add constraint FK_ROLE_SERVICE 
    foreign key (SERVICE_ID) 
    references SERVICES (SERVICE_ID);
