-- Copyright (c) 2012 Cloudera, Inc. All rights reserved.
--
-- Version 4509 of the CMF schema.
--
-- Create base role config groups as needed and update existing roles
-- to use them.
--

update SCHEMA_VERSION set VERSION=4509;

-- We're going to be adding role config groups, so let's temporarily enable
-- auto_increment  for the id column.
alter table ROLE_CONFIG_GROUPS
  modify column ROLE_CONFIG_GROUP_ID bigint not null auto_increment;

-- Insert new groups for each service/roletype combination (from existing
-- roles) that's not already represented by a group.
insert into ROLE_CONFIG_GROUPS (SERVICE_ID, ROLE_TYPE, NAME)
  (select distinct r.SERVICE_ID, r.ROLE_TYPE, CONCAT(r.ROLE_TYPE, '_BASE')
  from ROLES r left join ROLE_CONFIG_GROUPS g
  on r.SERVICE_ID=g.SERVICE_ID and r.ROLE_TYPE=g.ROLE_TYPE
  where g.SERVICE_ID is null);

-- Done inserting, disable auto_increment.
alter table ROLE_CONFIG_GROUPS
  modify column ROLE_CONFIG_GROUP_ID bigint not null;

-- Update all roles to point to the appropriate role config group.
update ROLES r
  set ROLE_CONFIG_GROUP_ID=(
    select ROLE_CONFIG_GROUP_ID
    from ROLE_CONFIG_GROUPS g
    where r.ROLE_TYPE=g.ROLE_TYPE and
          r.SERVICE_ID=g.SERVICE_ID);

-- Now that every role has a group, make the foreign key not nullable.
alter table ROLES
  modify column ROLE_CONFIG_GROUP_ID bigint not null;
